@@ -11,21 +11,21 @@
 #' @param x \code{bicop_dist object.}
 #' @param type plot type; either \code{"surface"} or \code{"contour"}.
 #' @param margins options are: \code{"unif"} for the original copula density,
-#' \code{"norm"} for the transformed density with standard normal margins,
-#' \code{"exp"} with standard exponential margins, and  \code{"flexp"} with
-#' flipped exponential margins. Default is \code{"norm"} for \code{type =
-#' "contour"}, and \code{"unif"} for \code{type = "surface"}.
+#'   \code{"norm"} for the transformed density with standard normal margins,
+#'   \code{"exp"} with standard exponential margins, and  \code{"flexp"} with
+#'   flipped exponential margins. Default is \code{"norm"} for \code{type =
+#'   "contour"}, and \code{"unif"} for \code{type = "surface"}.
 #' @param size integer; the plot is based on values on a \eqn{size x size} grid,
-#' default is 100.
+#'   default is 100.
 #' @param \dots optional arguments passed to \code{\link{contour}} or
-#' \code{\link{wireframe}}.
-#' @seealso \code{\link{bicop_dist}}, \code{\link{contour}}, \code{\link{wireframe}}
+#'   \code{\link{wireframe}}.
+#' @seealso [bicop_dist()], [graphics::contour()], [wireframe()]
 #' @keywords plot
 #' @examples
-#' 
+#'
 #' ## construct bicop_dist object for a student t copula
 #' obj <- bicop_dist(family = "t", rotation = 0, parameters = c(0.7, 4))
-#' 
+#'
 #' ## plots
 #' plot(obj) # surface plot of copula density
 #' contour(obj) # contour plot with standard normal margins
@@ -124,7 +124,10 @@ plot.bicop_dist <- function(x, type = "surface", margins, size, ...) {
   }
 
   ## evaluate on grid
+  vt <- x$var_types
+  x$var_types <- c("c", "c")
   vals <- dbicop(g, x)
+  x$var_types <- vt
   cop <- matrix(vals, size, size)
 
   ## adjust for margins
