@@ -1,19 +1,29 @@
 #' Vine copula distributions
 #'
-#' Density, distribution function and random generation
-#' for the vine copula distribution.
+#' Density, distribution function and random generation for the vine copula
+#' distribution.
 #'
 #' @name vinecop_distributions
 #' @aliases dvinecop pvinecop rvinecop dvinecop_dist pvinecop_dist rvinecop_dist
-#' @param u evaluation points, either a length d vector or a d-column matrix,
-#'   where d is the number of variables in the vine.
+#' @param u matrix of evaluation points; must contain at least d columns, where
+#'   d is the number of variables in the vine. More columns are required for
+#'   discrete models, see *Details*.
 #' @param vinecop an object of class `"vinecop_dist"`.
 #' @param cores number of cores to use; if larger than one, computations are
 #'   done in parallel on `cores` batches .
-#' @details
-#' See [vinecop] for the estimation and construction of vine copula models.
-#' Here, the density, distribution function and random generation
-#' for the vine copulas are standard.
+#' @details See [vinecop()] for the estimation and construction of vine copula
+#' models.
+#'
+#' ## Discrete variables
+#'
+#' When at least one variable is discrete, two types of
+#' "observations" are required in `u`: the first \eqn{n \; x \; d} block
+#' contains realizations of \eqn{F_{X_j}(X_j)}. The second \eqn{n \; x \; d}
+#' block contains realizations of \eqn{F_{X_j}(X_j^-)}. The minus indicates a
+#' left-sided limit of the cdf. For, e.g., an integer-valued variable, it holds
+#' \eqn{F_{X_j}(X_j^-) = F_{X_j}(X_j - 1)}. For continuous variables the left
+#' limit and the cdf itself coincide. Respective columns can be omitted in the
+#' second block.
 #'
 #' @return
 #' `dvinecop()` gives the density, `pvinecop()` gives the distribution function,
@@ -24,27 +34,37 @@
 #'
 #' The `vinecop` object is recycled to the length of the
 #' result.
+#'
+#' @seealso [vinecop_dist()], [vinecop()], [plot.vinecop()], [contour.vinecop()]
+#'
 #' @examples
-#' # specify pair-copulas
-#' bicop <- bicop_dist("bb1", 90, c(3, 2))
-#' pcs <- list(
-#'   list(bicop, bicop), # pair-copulas in first tree
-#'   list(bicop) # pair-copulas in second tree
-#' )
+#' ## simulate dummy data
+#' x <- rnorm(30) * matrix(1, 30, 5) + 0.5 * matrix(rnorm(30 * 5), 30, 5)
+#' u <- pseudo_obs(x)
 #'
-#' # specify R-vine matrix
-#' mat <- matrix(c(1, 2, 3, 1, 2, 0, 1, 0, 0), 3, 3)
-#'
-#' # set up vine copula model
-#' vc <- vinecop_dist(pcs, mat)
+#' ## fit a model
+#' vc <- vinecop(u, family = "clayton")
 #'
 #' # simulate from the model
-#' u <- rvinecop(200, vc)
+#' u <- rvinecop(100, vc)
 #' pairs(u)
 #'
 #' # evaluate the density and cdf
 #' dvinecop(u[1, ], vc)
 #' pvinecop(u[1, ], vc)
+#'
+#' ## Discrete models
+#' vc$var_types <- rep("d", 5)  # convert model to discrete
+#'
+#' # with discrete data we need two types of observations (see Details)
+#' x <- qpois(u, 1)  # transform to Poisson margins
+#' u_disc <- cbind(ppois(x, 1), ppois(x - 1, 1))
+#'
+#' dvinecop(u_disc[1:5, ], vc)
+#' pvinecop(u_disc[1:5, ], vc)
+#'
+#' # simulated data always has uniform margins
+#' pairs(rvinecop(200, vc))
 #' @rdname vinecop_methods
 #' @export
 dvinecop <- function(u, vinecop, cores = 1) {
@@ -100,10 +120,10 @@ summary.vinecop_dist <- function(object, ...) {
   d <- dim(object)[1]
   n_trees <- dim(object)[2]
   n_pcs <- length(unlist(object$pair_copulas, recursive = FALSE))
-  mdf <- as.data.frame(matrix(NA, n_pcs, 9))
+  mdf <- as.data.frame(matrix(NA, n_pcs, 10))
   names(mdf) <- c(
     "tree", "edge",
-    "conditioned", "conditioning",
+    "conditioned", "conditioning", "var_types",
     "family", "rotation", "parameters", "df", "tau"
   )
   k <- 1
@@ -114,6 +134,7 @@ summary.vinecop_dist <- function(object, ...) {
       mdf$conditioned[k] <- list(c(mat[d - e + 1, e], mat[t, e]))
       mdf$conditioning[k] <- list(mat[rev(seq_len(t - 1)), e])
       pc <- object$pair_copulas[[t]][[e]]
+      mdf$var_types[k] <- paste(pc$var_types, collapse = ",")
       mdf$family[k] <- pc$family
       mdf$rotation[k] <- pc$rotation
       mdf$parameters[k] <- list(pc$parameters)
@@ -141,12 +162,23 @@ summary.vinecop_dist <- function(object, ...) {
 #' @param n_mc number of samples used for quasi Monte Carlo integration when
 #'    `what = "cdf"`.
 #' @param cores number of cores to use; if larger than one, computations are
-#'   done in parallel on `cores` batches .
+#'   done in parallel on `cores` batches.
 #' @param ... unused.
 #'
 #' @details `fitted()` can only be called if the model was fit with the
 #'    `keep_data = TRUE` option.
 #'
+#' ## Discrete variables
+#'
+#' When at least one variable is discrete, two types of
+#' "observations" are required in `newdata`: the first \eqn{n \; x \; d} block
+#' contains realizations of \eqn{F_{X_j}(X_j)}. The second \eqn{n \; x \; d}
+#' block contains realizations of \eqn{F_{X_j}(X_j^-)}. The minus indicates a
+#' left-sided limit of the cdf. For, e.g., an integer-valued variable, it holds
+#' \eqn{F_{X_j}(X_j^-) = F_{X_j}(X_j - 1)}. For continuous variables the left
+#' limit and the cdf itself coincide. Respective columns can be omitted in the
+#' second block.
+#'
 #' @return
 #' `fitted()` and `predict()` have return values similar to [dvinecop()]
 #' and [pvinecop()].
@@ -154,7 +186,7 @@ summary.vinecop_dist <- function(object, ...) {
 #' @rdname predict_vinecop
 #' @examples
 #' u <- sapply(1:5, function(i) runif(50))
-#' fit <- vinecop(u, "par", keep_data = TRUE)
+#' fit <- vinecop(u, family = "par", keep_data = TRUE)
 #' all.equal(predict(fit, u), fitted(fit))
 predict.vinecop <- function(object, newdata, what = "pdf", n_mc = 10^4,
                             cores = 1, ...) {
@@ -200,31 +232,29 @@ logLik.vinecop <- function(object, ...) {
 #'
 #' The modified vine copula Bayesian information criterion (mBICv) is defined as
 #'
-#' \deqn{BIC = -2 loglik +  \nu log(n) - 2
-#' \sum_{t=1}^{d - 1} (q_t log(\psi_0^t) - (d - t - q_t) log(1 - \psi_0^t))
-#' }
+#' \deqn{BIC = -2 loglik +  \nu log(n) - 2 \sum_{t=1}^{d - 1} (q_t log(\psi_0^t)
+#' - (d - t - q_t) log(1 - \psi_0^t)) }
 #'
 #' where \eqn{\mathrm{loglik}} is the log-likelihood and \eqn{\nu} is the
 #' (effective) number of parameters of the model, \eqn{t} is the tree level
 #' \eqn{\psi_0} is the prior probability of having a non-independence copula and
-#' \eqn{q_t} is the number of non-independence copulas in tree \eqn{t}.
-#' The mBICv is a consistent model selection criterion for parametric sparse
-#' vine copula models.
+#' \eqn{q_t} is the number of non-independence copulas in tree \eqn{t}. The
+#' mBICv is a consistent model selection criterion for parametric sparse vine
+#' copula models.
 #'
 #' @param object a fitted `vinecop` object.
 #' @param psi0 baseline prior probability of a non-independence copula.
 #' @param newdata optional; a new data set.
 #'
-#' @references Nagler, T., Bumann, C., Czado, C. (2019).
-#' Model selection for sparse high-dimensional vine copulas with application
-#' to portfolio risk.
-#' *Journal of Multivariate Analysis, in press*
-#' (\url{https://arxiv.org/pdf/1801.09739.pdf})
+#' @references Nagler, T., Bumann, C., Czado, C. (2019). Model selection for
+#'   sparse high-dimensional vine copulas with application to portfolio risk.
+#'   *Journal of Multivariate Analysis, in press*
+#'   (\url{https://arxiv.org/pdf/1801.09739.pdf})
 #'
 #' @export mBICV
 #' @examples
 #' u <- sapply(1:5, function(i) runif(50))
-#' fit <- vinecop(u, "par", keep_data = TRUE)
+#' fit <- vinecop(u, family = "par", keep_data = TRUE)
 #' mBICV(fit, 0.9) # with a 0.9 prior probability of a non-independence copula
 #' mBICV(fit, 0.1) # with a 0.1 prior probability of a non-independence copula
 mBICV <- function(object, psi0 = 0.9, newdata = NULL) {
