@@ -13,19 +13,19 @@
 #'
 #' @aliases contour.vinecop_dist plot.vinecop contour.vinecop
 #'
-#' @inheritParams plot.bicop_dist
 #' @param x \code{vinecop_dist} object.
 #' @param tree \code{"ALL"} or integer vector; specifies which trees are
 #' plotted.
-#' @param var_names integer; specifies how to make use of variable names: \cr
-#' \code{"ignore"} = variable names are ignored,
-#' \cr \code{"use"} = variable names are used to annotate vertices,
-#' \cr \code{"legend"} = uses numbers in plot and adds a legend for variable names.
+#' @param var_names integer; specifies how to make use of variable names:
+#' * `"ignore"`` = variable names are ignored,
+#' * `"use"`` = variable names are used to annotate vertices,
+#' * `"legend"`` = uses numbers in plot and adds a legend for variable names.
 #' @param edge_labels character; either a vector of edge labels or one of the
-#' following: \cr \code{"family"} = pair-copula family (see
-#' \code{\link[rvinecopulib:bicop_dist]{bicop_dist}}), \cr \code{"tau"} =
-#' pair-copula Kendall's tau\cr \code{"family_tau"} = pair-copula family and
-#' Kendall's tau, \cr \code{"pair"} = for the name of the involved variables.
+#' following:
+#' * `"family"` = pair-copula family (see `[bicop_dist()]`),
+#' * `"tau"`` = pair-copula Kendall's tau
+#' * `"family_tau"`` = pair-copula family and Kendall's tau,
+#' * `"pair"`` = the name of the involved variables.
 #' @param cex.nums numeric; expansion factor for font of the numbers.
 #' @param \dots Unused for \code{plot} and passed to
 #' \code{\link[rvinecopulib:contour.bicop]{contour.bicop}} for \code{contour}.
@@ -42,18 +42,18 @@
 #' d <- 20
 #' n <- 2e2
 #' u <- matrix(runif(n * d), n, d)
-#' vc <- vinecop(u, "indep")
-#' 
+#' vc <- vinecop(u, family = "indep")
+#'
 #' # plot
 #' plot(vc, tree = c(1, 2))
 #' plot(vc, edge_labels = "pair")
-#' 
+#'
 #' # set up another vine copula model
 #' pcs <- lapply(1:3, function(j) # pair-copulas in tree j
 #'   lapply(runif(4 - j), function(cor) bicop_dist("gaussian", 0, cor)))
-#' mat <- matrix(c(1, 2, 3, 4, 1, 2, 3, 0, 1, 2, 0, 0, 1, 0, 0, 0), 4, 4)
+#' mat <- rvine_matrix_sim(4)
 #' vc <- vinecop_dist(pcs, mat)
-#' 
+#'
 #' # contour plot
 #' contour(vc)
 #' @export
@@ -87,7 +87,7 @@ plot.vinecop_dist <- function(x, tree = 1, var_names = "ignore",
       ))
       tree <- c(1, 2)
     } else {
-      tree <- 1:trunc_lvl
+      tree <- seq_len(trunc_lvl)
     }
   }
   assert_that(in_set(var_names, c("ignore", "use", "legend")))
@@ -260,7 +260,7 @@ contour.vinecop_dist <- function(x, tree = "ALL", cex.nums = 1, ...) {
   )
 
   if (any(tree == "ALL")) {
-    tree <- 1:trunc_lvl
+    tree <- seq_len(trunc_lvl)
   }
 
   n_tree <- length(tree)
