@@ -20,26 +20,26 @@ namespace vinecopulib {
 class Bb6Bicop : public ArchimedeanBicop
 {
 public:
-    // constructor
-    Bb6Bicop();
+  // constructor
+  Bb6Bicop();
 
 private:
-    // generator, its inverse and derivatives for the archimedean copula
-    double generator(const double &u);
+  // generator, its inverse and derivatives for the archimedean copula
+  double generator(const double& u);
 
-    double generator_inv(const double &u);
+  double generator_inv(const double& u);
 
-    double generator_derivative(const double &u);
+  double generator_derivative(const double& u);
 
-    double generator_derivative2(const double &u);
+  double generator_derivative2(const double& u);
 
-    // pdf
-    Eigen::VectorXd pdf_raw(const Eigen::Matrix<double, Eigen::Dynamic, 2> &u);
+  // pdf
+  Eigen::VectorXd pdf_raw(const Eigen::MatrixXd& u);
 
-    // link between Kendall's tau and the par_bicop parameter
-    double parameters_to_tau(const Eigen::MatrixXd &par);
+  // link between Kendall's tau and the par_bicop parameter
+  double parameters_to_tau(const Eigen::MatrixXd& par);
 
-    Eigen::MatrixXd tau_to_parameters(const double &tau);
+  Eigen::MatrixXd tau_to_parameters(const double& tau);
 };
 }
 
