@@ -3,7 +3,8 @@ context("Class 'bicop_dist'")
 test_that("constructor creates proper bicop_dist object", {
   dist <- bicop_dist("gumbel", 90, 3)
   expect_s3_class(dist, "bicop_dist")
-  expect_identical(names(dist), c("family", "rotation", "parameters", "npars"))
+  expect_identical(names(dist),
+                   c("family", "rotation", "parameters", "var_types", "npars"))
 })
 
 
